@@ -75,7 +75,7 @@ class BaseCacheMixin:
 
 
 class GetCacheMixin:
-    def _get(self, url) -> dict:
+    def _get(self, url=None) -> dict:
         if url is None and self._cache is not None:
             return self._cache
         return super()._get(url=url)
@@ -86,11 +86,13 @@ class CacheMixin(GetCacheMixin, BaseCacheMixin):
     def __init__(self,
                  user,
                  query_params: dict = None,
+                 action: str = None,
                  is_async: bool = False,
                  timeout: tuple = (30, 30)
                  ):
         super().__init__(user=user,
                          query_params=query_params,
+                         action=action,
                          is_async=is_async,
                          timeout=timeout,
                          )
@@ -114,11 +116,13 @@ class CacheObjectMixin(GetCacheMixin, BaseCacheMixin):
     def __init__(self,
                  user,
                  lookup_field_value: Union[str, int],
+                 action: str = None,
                  is_async: bool = False,
                  timeout: tuple = (30, 30)
                  ):
         super().__init__(user=user,
                          lookup_field_value=lookup_field_value,
+                         action=action,
                          is_async=is_async,
                          timeout=timeout
                          )
