@@ -13,9 +13,9 @@ __all__ = ('PointError',
 from typing import OrderedDict, Union
 
 from django.contrib.auth import get_user_model
+from rest_framework import status
 from rest_framework.exceptions import ValidationError
 
-from expressmoney.utils import status
 from expressmoney.api.cache import CacheMixin, CacheObjectMixin
 from expressmoney.api.contract import Contract
 from expressmoney.api.filter import FilterMixin
@@ -78,7 +78,6 @@ class PointThrottled(PointClientError):
 
 
 class Point:
-    """Base endpoint handler"""
     _point_id: ID = None
 
     @log
@@ -147,7 +146,7 @@ class Point:
         if not self._is_async:
             if not status.is_success(response.status_code):
                 if status.is_client_error(response.status_code):
-                    if status.is_not_found(response.status_code):
+                    if response.status_code == status.HTTP_404_NOT_FOUND:
                         self._cache = status.HTTP_404_NOT_FOUND
                         raise PointNotFound404(self._client.url)
                     if response.status_code == status.HTTP_429_TOO_MANY_REQUESTS:
@@ -269,8 +268,8 @@ class ContractObjectPoint(CacheObjectMixin, ObjectPoint):
     _update_contract = None
 
     def _get_validated_data(self):
-        data = self._get(url=None)
-        if status.is_not_found(data):
+        data = self._get()
+        if data == status.HTTP_404_NOT_FOUND:
             raise PointNotFound404
         contract = self._get_contract(data, True)
         validated_data = contract.validated_data
@@ -296,8 +295,6 @@ class ContractObjectPoint(CacheObjectMixin, ObjectPoint):
 
 
 class ListPointMixin:
-    """For type ContractPoint"""
-
     def list(self) -> tuple:
         if self._read_contract is None:
             raise PointError(f'Set attr read_contract')
@@ -305,8 +302,6 @@ class ListPointMixin:
 
 
 class RetrievePointMixin:
-    """For type ContractObjectPoint"""
-
     def retrieve(self) -> OrderedDict:
         if self._read_contract is None:
             raise PointError(f'Set attr read_contract')
@@ -314,8 +309,6 @@ class RetrievePointMixin:
 
 
 class CreatePointMixin:
-    """For type ContractPoint"""
-
     def create(self, payload: dict):
         if self._create_contract is None:
             raise PointError(f'Set attr create_contract')
@@ -324,8 +317,6 @@ class CreatePointMixin:
 
 
 class UpdatePointMixin:
-    """For type ContractObjectPoint"""
-
     def update(self, payload: dict):
         if self._update_contract is None:
             raise PointError(f'Set attr update_contract')
@@ -335,8 +326,6 @@ class UpdatePointMixin:
 
 
 class ResponseMixin:
-    """Only for create and update"""
-
     _response_contract = None
 
     @property
@@ -353,7 +342,5 @@ class ResponseMixin:
 
 
 class UploadFilePointMixin:
-    """For any type Point"""
-
     def upload_file(self, file, filename: str, file_type: int):
         self._post_file(file, filename, file_type)
